@@ -75,16 +75,15 @@ class FuncLister(ast.NodeVisitor):
 
 def get_label_info(label):
     tokfile = expanduser('~') + sep + '.infinstor' + sep + '/token'
-    token, refresh_token, token_time, client_id, service = read_token_file(tokfile)
+    token, refresh_token, token_time, client_id, service, token_type = read_token_file(tokfile)
 
-    payload = ("label=" + label)
     headers = {
         'Content-Type': 'application/x-www-form-urlencoded',
         'Authorization': token
         }
-    url = 'https://api.' + service + '.com/listlabels'
+    url = 'https://mlflow.' + service + '.com/api/2.0/mlflow/label/get?labelname=' + label
     try:
-        response = requests.post(url, data=payload, headers=headers)
+        response = requests.post(url, headers=headers)
         response.raise_for_status()
     except HTTPError as http_err:
         print(f'HTTP error occurred: {http_err}')
@@ -92,26 +91,20 @@ def get_label_info(label):
     except Exception as err:
         print(f'Other error occurred: {err}')
         raise
-    labels = response.json()['labels']
-    for one_label in labels:
-        labelname = one_label['label']
-        if (labelname == label):
-            return one_label['timespec'], one_label['bucketname'], one_label['prefix'], service
-        else:
-            return None, None, None, None
+    label = response.json()['label']
+    return label['timespec']['S'], label['bucketname']['S'], label['prefix']['S'], service
 
 def get_xform_info(xformname):
     tokfile = expanduser('~') + sep + '.infinstor' + sep + '/token'
-    token, refresh_token, token_time, client_id, service = read_token_file(tokfile)
+    token, refresh_token, token_time, client_id, service, token_type = read_token_file(tokfile)
 
-    payload = ("xformname=" + xformname)
     headers = {
         'Content-Type': 'application/x-www-form-urlencoded',
         'Authorization': token
         }
-    url = 'https://api.' + service + '.com/listxforms'
+    url = 'https://mlflow.' + service + '.com/api/2.0/mlflow/xform/get?transform_name=' + xformname
     try:
-        response = requests.post(url, data=payload, headers=headers)
+        response = requests.get(url, headers=headers)
         response.raise_for_status()
     except HTTPError as http_err:
         print(f'HTTP error occurred: {http_err}')
@@ -119,16 +112,11 @@ def get_xform_info(xformname):
     except Exception as err:
         print(f'Other error occurred: {err}')
         raise
-    xforms = response.json()['xforms']
-    for xform in xforms:
-        xfn = xform['xformname']
-        if (xfn == xformname):
-            if ('dockerfile' in xform):
-                return xform['xformcode'], xform['dockerfile']
-            else:
-                return xform['xformcode'], None
-    return None, None
-
+    xform = response.json()['transform']
+    if ('dockerfile' in xform):
+        return xform['xformcode']['S'], xform['dockerfile']['S']
+    else:
+        return xform['xformcode']['S'], None
 
 def download_one_dir(label):
     timespec, bucketname, prefix, service = get_label_info(label)
@@ -828,11 +816,26 @@ def generate_cache_key(input_data_spec, xformname):
         raise ValueError('Error. Unknown input_data_spec type ' + input_data_spec['type'])
     return cache_key
 
+def generate_input_data_spec_string(input_data_spec):
+    if (input_data_spec['type'] == 'infinsnap'):
+        rv = 'infinsnap/' + input_data_spec['time_spec'] + '/' + input_data_spec['bucketname']\
+                + '/' + input_data_spec['prefix']
+    elif (input_data_spec['type'] == 'infinslice'):
+        rv = 'infinslice/' + input_data_spec['time_spec'] + '/' + input_data_spec['bucketname']\
+                + '/' + input_data_spec['prefix']
+    elif (input_data_spec['type'] == 'label'):
+        rv = 'label/' + input_data_spec['label']
+    elif (input_data_spec['type'] == 'mlflow-run-artifacts'):
+        rv = 'run_id/' + input_data_spec['run_id']
+    else:
+        raise ValueError('Error. Unknown input_data_spec type ' + input_data_spec['type'])
+    return rv
+
 def check_in_cache(input_data_spec, xformname):
     cache_key = generate_cache_key(input_data_spec, xformname)
 
     all_experiments = [exp.experiment_id for exp in MlflowClient().list_experiments()]
-    query = "params.input_data_spec = '" + cache_key + "'"
+    query = "params.cache_key = '" + cache_key + "'"
     runs = MlflowClient().search_runs(experiment_ids=all_experiments,
             filter_string=query, run_view_type=ViewType.ACTIVE_ONLY)
     if (len(runs) == 0):
@@ -844,7 +847,7 @@ def check_in_cache(input_data_spec, xformname):
         return False, None
     
 
-def run_transform_inline(service_name, input_data_spec, xformname, **kwargs):
+def run_transform_inline(service_name, run_id, input_data_spec, xformname, **kwargs):
     cache_key = generate_cache_key(input_data_spec, xformname)
     if (input_data_spec['type'] == 'infinsnap' or input_data_spec['type'] == 'infinslice'):
         endpoint = "https://" + input_data_spec['time_spec'] + ".s3proxy."\
@@ -871,7 +874,9 @@ def run_transform_inline(service_name, input_data_spec, xformname, **kwargs):
     if (transform_string == None):
         raise ValueError('Error. Cannot find xform ' + xformname)
 
-    log_param('input_data_spec', cache_key)
+    log_param('run_id', run_id)
+    log_param('cache_key', cache_key)
+    log_param('input_data_spec', generate_input_data_spec_string(input_data_spec))
     xobjects = run_transform_string_inline(client, bucketname, prefix_in,\
                 transform_string, **kwargs)
     return xobjects
@@ -1019,7 +1024,8 @@ def run_transform(run_options, **kwargs):
         else:
             nes = False
         with start_run(nested=nes) as run:
-            xobjects = run_transform_inline(service_name, input_data_spec, xformname, **kwargs)
+            xobjects = run_transform_inline(service_name, run.info.run_id,
+                    input_data_spec, xformname, **kwargs)
             return run.info.run_id
     elif (run_location == "singlevm"):
         instance_type = run_options.pop('instance_type')
@@ -1036,7 +1042,11 @@ def run_transform(run_options, **kwargs):
 
 def run_transforms(transforms):
     if (len(transforms) == 1):
-        return run_transform(transforms[0]['run_options'], **transforms[0]['kwargs'])
+        transform = transforms[0]
+        if ('kwargs' in transform and transform['kwargs'] != None):
+            return run_transform(transform['run_options'], **transform['kwargs'])
+        else:
+            return run_transform(transform['run_options'])
 
     run = start_run()
     parent_run_id = run.info.run_id
