@@ -2,6 +2,7 @@ import sys
 import argparse
 from . import run_transform_inline
 import json
+from mlflow import start_run
 
 def main():
     parser = argparse.ArgumentParser()
@@ -19,9 +20,13 @@ def main():
     print(str(kwa))
     input_data_spec = json.loads(args.input_data_spec)
     if (len(kwa.items()) > 0):
-        return run_transform_inline(args.service, input_data_spec, args.xformname, **kwa)
+        with start_run() as run:
+            return run_transform_inline(args.service, run.info.run_id,
+                input_data_spec, args.xformname, **kwa)
     else:
-        return run_transform_inline(args.service, input_data_spec, args.xformname)
+        with start_run() as run:
+            return run_transform_inline(args.service, run.info.run_id,
+                input_data_spec, args.xformname)
 
 if __name__ == "__main__":
     main()
